package Common;

# $Id$
# $URL$
use strict;
use warnings;
use ldapBase;
use constant CONFIG => (
    { CASE => 1 },
    GLOBAL => { DEFAULT => undef },

    # * common *
    add    => { ARGS => "!", ALIAS => [qw/new create/] },
    list   => { ARGS => "!", ALIAS => "ls" },
    modify => { ARGS => "!", ALIAS => "change" },
    delete => { ARGS => "!", ALIAS => "remove" },

    ldap_base => {
        ARGS    => "=s",
        DEFAULT => ldapBase(qw(/etc/openldap/ldap.conf /etc/ldap/ldap.conf))
    },
    ldap_server => { ARGS => "=s", DEFAULT => "localhost" },
    ldap_bind_dn =>
      { ARGS => "=s", DEFAULT => "cn=admin", ALIAS => "ldap_admin" },
    ldap_password => { ARGS => "=s" },

    help  => { ARGS => "!" },
    debug => { ARGS => "!" },

    description => { ARGS => "=s" },

    # * account *
    default_domain => { ARGS => "=s", DEFAULT => "" },
    imap_server    => { ARGS => "=s", DEFAULT => "localhost" },
    imap_port      => { ARGS => "=s", DEFAULT => "143" },
    imap_admin     => { ARGS => "=s", DEFAULT => $ENV{USER} },
    imap_password  => { ARGS => "=s" },
    imap_quota =>
      { ARGS => "=i", DEFAULT => 300 * 1024 * 1024, ALIAS => "quota" },
    imap_aclgroups => { ARGS => "=s", ALIAS => "aclgroups" },

    # dovecots mail_location (%1, %u & %d supported)
    imap_mail_location =>
      { ARGS => "=s", DEFAULT => '/var/vmail/users/%d/%1/%u' },

    mbox     => { ARGS => "!", DEFAULT => 1 },
    password => { ARGS => "=s" },

    #   internal =>	    { ARGS => "!",  DEFAULT => ":", ALIAS => "restricted" },

    other    => { ARGS => ":s" },
    group    => { ARGS => ":s" },
    forward  => { ARGS => ":s" },
    fullname => { ARGS => "=s", ALIAS => "realname" },
    address  => { ARGS => "=s", ALIAS => "primary" },

    # * acl *
    acl_admin    => { ARGS => "=s" },
    acl_password => { ARGS => "=s" },
    folder       => { ARGS => ":s@" },
    acl          => { ARGS => "=s" },
    recursive    => { ARGS => "!", DEFAULT => 0 },

    # * alias * group *
    members => { ARGS => ":s" },

    # * shared *
    #access =>	    { ARGS => ":s" },

    # * group *
    gid_min => { ARGS => "=i", DEFAULT => 60000 },
    gid_max => { ARGS => "=i", DEFAULT => 60100 },

    # * ldap intern *
    ldap_ou_aliases  => { ARGS => "=s", DEFAULT => "ou=MailAliases" },
    ldap_ou_accounts => { ARGS => "=s", DEFAULT => "ou=MailAccounts" },
    ldap_ou_groups   => { ARGS => "=s", DEFAULT => "ou=Groups" },

    ldap_oc_alias       => { ARGS => "=s", DEFAULT => "XXXmailAlias" },
    ldap_oc_recipient   => { ARGS => "=s", DEFAULT => "XXXmailRecipient" },
    ldap_oc_accessgroup => { ARGS => "=s", DEFAULT => "XXXmailAccessGroup" },

    ldap_at_address   => { ARGS => "=s", DEFAULT => "XXXmailAddress" },
    ldap_at_group     => { ARGS => "=s", DEFAULT => "XXXmailGroup" },
    ldap_at_quota     => { ARGS => "=s", DEFAULT => "XXXmailQuota" },
    ldap_at_aclgroups => { ARGS => "=s", DEFAULT => "XXXmailACLGroups" },
    ldap_at_forwardingaddress =>
      { ARGS => "=s", DEFAULT => "XXXmailForwardingAddress" },
    ldap_at_primaryaddress =>
      { ARGS => "=s", DEFAULT => "XXXmailPrimaryAddress" },

);

{
    my @pw;

    sub mkpw($) {
        my $in = $_[0];

        return $in unless $in and $in eq "{pwgen}";

        if ( !@pw ) {
            chomp( @pw = `pwgen -nc 12 1 2>/dev/null` );
            die "pwgen: $!" if $?;
        }
        return shift @pw;

    }
}

1;
